@@ -326,6 +326,34 @@ The URI handling code
 
 The DBus handling code
 
+=item Sys::Virt::Error::FROM_DEVICE
+
+The device handling code
+
+=item Sys::Virt::Error::FROM_SSH
+
+The libSSH2 socket client
+
+=item Sys::Virt::Error::FROM_PARALLELS
+
+The Parallels virtualization driver
+
+=item Sys::Virt::Error::FROM_LOCKSPACE
+
+The lockspace handling code
+
+=item Sys::Virt::Error::FROM_INITCTL
+
+The initctl client code
+
+=item Sys::Virt::Error::FROM_CGROUP
+
+The cgroups code
+
+=item Sys::Virt::Error::FROM_IDENTITY
+
+The identity management code
+
 =back
 
 =head2 ERROR CODE CONSTANTS
@@ -672,6 +700,22 @@ The calculation would overflow
 
 Action prevented by block copy job
 
+=item Sys::Virt::Error::ERR_AGENT_UNRESPONSIVE
+
+The guest agent is not responding
+
+=item Sys::Virt::Error::ERR_OPERATION_UNSUPPORTED
+
+The operation is not supported on this host
+
+=item Sys::Virt::Error::ERR_SSH
+
+The SSH operation failed
+
+=item Sys::Virt::Error::ERR_RESOURCE_BUSY
+
+The resource requested is already in use
+
 =back
 
 =head1 AUTHORS
